//#17.0.1.0 WDZRNavigateur.js
//VersionVI: 30F170056e
// Le seul support technique disponible pour cette librairie est
// accessible a travers le service "Assistance Directe".

// Manipulation des champs zone repetee navigateur

// Une ligne de la zone repetee navigateur
function WDZRLigne (nNbColonnes)
{
	if (nNbColonnes !== undefined)
	{
		// Tableaux des valeurs
		this.m_tabValeurs = new Array(nNbColonnes);
		// Etat d'enroulement de la ligne : complement deroule
		// Pour le cache de l'etat, on ne garde par un flag par rupture effective mais on a le flag en general et il n'est lut que si on a une rupture
		// Plus on stocke l'etat dans un entier et on lit les bits (ce qui limite en pratique a 32 ruptures)
		// Cela evite des couteux tableaux d'etats
		this.m_nDeroule = this.ms_nTous;
		// Pareil pour les ruptures
		// L'etat sera MAJ lors de l'ajout dans la table
		this.m_nRupturesHaut = this.ms_nRien;
		this.m_nRupturesBas = this.ms_nRien;
	}
};

WDZRLigne.prototype.ms_nRien = 0;
WDZRLigne.prototype.ms_nTous = 0xFFFFFFFF;

// Lecture des valeurs
WDZRLigne.prototype.tabGetValeurs = function tabGetValeurs ()
{
	return this.m_tabValeurs;
};

// Indique si on a une rupture
WDZRLigne.prototype.bGetRupture = function bGetRupture (nRupture)
{
	return (0 != (this.m_nRupturesHaut & (1 << nRupture)));
};

// Notifie de la suppression de la ligne
WDZRLigne.prototype.OnSupprime = function OnSupprime ()
{
	// Libere explictement la memoire
	this.m_tabValeurs.length = 0;
};

// Enroule/deroule une rupture de la ligne
WDZRLigne.prototype.EnrouleDeroule = function EnrouleDeroule (nRupture, bDeroule, bRecursif)
{
	var nBit = 1 << nRupture;
	// Calcule l'inversion si besoin
	if (bDeroule === undefined)
	{
		bDeroule = (0 == (this.m_nDeroule & nBit));
	}
	if (bDeroule)
	{
		this.m_nDeroule |= nBit;
		// Plus deroule si demande les ruptures precedentes
		if (bRecursif && (0 < nRupture))
		{
			this.EnrouleDeroule(nRupture - 1, bDeroule, bRecursif);
		}
	}
	else
	{
		this.m_nDeroule &= ~nBit;
	}
};

// Enroule/deroule toutes les ruptures de la ligne
WDZRLigne.prototype.EnrouleDerouleTout = function EnrouleDerouleTout(bDeroule)
{
	this.m_nDeroule = bDeroule ? this.ms_nTous : this.ms_nRien;
};

// Fixe les ruptures
WDZRLigne.prototype.SetRupturesHaut = function SetRupturesHaut(nRuptures)
{
	// Prepare au deroule les ruptures modifiees
	var nDeroule = this.m_nRupturesHaut ^ nRuptures;

	this.m_nRupturesHaut = nRuptures;
	// Deroule les ruptures modifiees
	this.m_nDeroule |= nDeroule;
};
WDZRLigne.prototype.SetRupturesBas = function SetRupturesBas(nRuptures)
{
	this.m_nRupturesBas = nRuptures;
};

// Lit les ruptures
WDZRLigne.prototype.nGetRupturesHaut = function nGetRupturesHaut()
{
	return this.m_nRupturesHaut;
};
WDZRLigne.prototype.nGetRupturesBas = function nGetRupturesBas()
{
	return this.m_nRupturesBas;
};

// Une rupture de la zone repetee navigateur
function WDZRRupture (sAlias, nColonne)
{
	if (sAlias)
	{
		this.m_sAlias = sAlias;
		this.m_nColonne = nColonne;
	}
};

// Une colonne/un attribut de la zone repetee navigateur
function WDZRColonne(sAlias, eProprieteAssocie)
{
	if (sAlias)
	{
		this.m_sAlias = sAlias;
		this.m_eProprieteAssocie = eProprieteAssocie;
	}
};

WDZRColonne.prototype.oGetValeurInterne = function oGetValeurInterne(sValeur)
{
	if (sValeur !== undefined)
	{
		var oTemp;
		switch (this.m_eProprieteAssocie)
		{
		case WDChamp.prototype.XML_CHAMP_PROP_NUM_VISIBLE:
		case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICEGRAS:
		case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICEITALIQUE:
		case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICESOULIGNE:
			return (false != sValeur);
		case WDChamp.prototype.XML_CHAMP_PROP_NUM_ETAT:
			oTemp = parseInt(sValeur + "", 10);
			if ((oTemp != WDChamp.prototype.ms_eEtatActif) && (oTemp != WDChamp.prototype.ms_eEtatLectureSeule) && (oTemp != WDChamp.prototype.ms_eEtatGrise))
			{
				oTemp = WDChamp.prototype.ms_eEtatActif;
			}
			return oTemp;
		case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICETAILLE:
			// Une taille chaine est possible
		default:
			// @@@ : Selon le type de la colonne
			return (sValeur + "");
		}
	}
	else
	{
		return this.__oGetValeurDefaut();
	}
};

WDZRColonne.prototype.__oGetValeurDefaut = function __oGetValeurDefaut()
{
	switch (this.m_eProprieteAssocie)
	{
	case WDChamp.prototype.XML_CHAMP_PROP_NUM_VISIBLE:
		return true;
	case WDChamp.prototype.XML_CHAMP_PROP_NUM_ETAT:
		return WDChamp.prototype.ms_eEtatActif;
	case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICEGRAS:
	case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICEITALIQUE:
	case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICESOULIGNE:
		return false;
	case WDChamp.prototype.XML_CHAMP_PROP_NUM_POLICETAILLE:
		return 0;
	default:
		// @@@ : Selon le type de la colonne
		return "";
	}
};

WDZRColonne.prototype.fGetCompare = function fGetCompare(bCommencePar)
{
	// @@@ : Selon le type de la colonne et ses options
	return bCommencePar ? this.nCompareChaineCommencePar : this.nCompareChaine;
};

WDZRColonne.prototype.nCompareChaine = function nCompareChaine(sValeur1, sValeur2)
{
	if (sValeur1 < sValeur2)
	{
		return -1;
	}
	else if (sValeur1 > sValeur2)
	{
		return 1;
	}
	else
	{
		return 0;
	}
};
WDZRColonne.prototype.nCompareChaineCommencePar = function nCompareChaineCommencePar(sValeur1, sValeur2)
{
	var nLongeur = Math.min(sValeur1.length, sValeur2.length);
	return this.nCompareChaine(sValeur1.substring(0, nLongeur), sValeur2.substring(0, nLongeur));
};

// Manipulation d'une zone repetee galerie
function WDZRNavigateur(sAliasChamp, tabCouleurFond, nNbLignesLogiquesParLignePhysique)
{
	// Si on est pas dans l'init d'un protoype
	if (sAliasChamp)
	{
		// Appel le constructeur de la classe de base
		WDChamp.prototype.constructor.apply(this, [sAliasChamp, undefined, undefined]);

		// Tableaux des lignes
		this.m_tabLignes = [];
		// Tableaux des attributs/colonnes
		this.m_tabColonnes = [];
		// Tableaux des ruptures
		this.m_tabRuptures = [];
		// Tri (tableau d'objets)
		this.m_tabTri = [];
		// Couleur de fond
		this.m_tabCouleurFond = tabCouleurFond;
		// Nombre de colonnes de la ZR
		this.m_nNbLignesLogiquesParLignePhysique = nNbLignesLogiquesParLignePhysique;
	}
};

// Declare l'heritage
WDZRNavigateur.prototype = new WDChampParametresHote();
// Surcharge le constructeur qui a ete efface
WDZRNavigateur.prototype.constructor = WDZRNavigateur;

WDZRNavigateur.prototype.ms_nLigneInvalide = -1;
WDZRNavigateur.prototype.ms_sDynO = "[%";
WDZRNavigateur.prototype.ms_sDynF = "%]";
WDZRNavigateur.prototype.ms_sDynSi = "[%SI%]";
WDZRNavigateur.prototype.ms_sDynAlors = "[%ALORS%]";
WDZRNavigateur.prototype.ms_sDynFin = "[%FIN%]";
WDZRNavigateur.prototype.ms_sConditionEgal = "=";
WDZRNavigateur.prototype.ms_sConditionDifferent = "!=";
WDZRNavigateur.prototype.ms_sPropriete = "..";
WDZRNavigateur.prototype.ms_sConversion = ";";
WDZRNavigateur.prototype.ms_nAttributRuptureLigneDebut = -1;
WDZRNavigateur.prototype.ms_nAttributRuptureLigneFin = -2;

// Initialisation :
WDZRNavigateur.prototype.Init = function Init()
{
	// Appel de la methode de la classe de base
	WDChampParametresHote.prototype.Init.apply(this, arguments);

	// Parse le HTML
	this.__HTMLParse();

	// Initialise la valeur des champs cache
	this.m_oChampDeb.value = "1";
	this.m_oChampOcc.value = "0";
	this.m_oChampFormulaire.value = "0";
};

// Trouve les divers elements : liaison avec le HTML
WDZRNavigateur.prototype._vLiaisonHTML = function _vLiaisonHTML(sSuffixeHote)
{
	// Appel de la methode de la classe de base
	WDChampParametresHote.prototype._vLiaisonHTML.apply(this, arguments);

	// Recupere les differents champs caches
	this.m_oChampDeb = this.oGetElementByName(document, "_DEB");
	this.m_oChampOcc = document.getElementsByName("_" + this.m_sAliasChamp + "_OCC")[0];
};

// Trouve le champ formulaire
WDZRNavigateur.prototype._voGetChampFormulaire = function _voGetChampFormulaire()
{
	// Ignore l'implementation avec _DATA de WDChampParametres
	// Il doit y avoir une meilleure solution (en particulier deplacer le code lie au ZR dans WDChamp mais cela va faire des effets de bord a l'init)
	return WDChamp.prototype._voGetChampFormulaire.apply(this, arguments);
};

// Interface de declaration
WDZRNavigateur.prototype.DeclareColonne = function DeclareColonne(sAlias, eProprieteAssocie)
{
	this.m_tabColonnes.push(new WDZRColonne(sAlias, eProprieteAssocie));
};
WDZRNavigateur.prototype.DeclareRupture = function DeclareRupture(sAlias, nColonne)
{
	this.m_tabRuptures.push(new WDZRRupture(sAlias, nColonne));
};

// Occurrence de la ZR
WDZRNavigateur.prototype._nGetNbLignes = function _nGetNbLignes()
{
	return this.m_tabLignes.length;
};

// Nombre de attributs/colonnes de la ZR
WDZRNavigateur.prototype._nGetNbColonnes = function _nGetNbColonnes()
{
	return this.m_tabColonnes.length;
};

// Nombre de rupture de la ZR
WDZRNavigateur.prototype._nGetNbRuptures = function _nGetNbRuptures()
{
	return this.m_tabRuptures.length;
};

WDZRNavigateur.prototype._nGetRuptureSelonAlias = function _nGetRuptureSelonAlias(sAliasRupture)
{
	var tabRuptures = this.m_tabRuptures;
	var i;
	var nLimiteI = this._nGetNbRuptures();
	for (i = 0; i < nLimiteI; i++)
	{
		if (tabRuptures[i].m_sAlias == sAliasRupture)
		{
			return i;
		}
	}
	return undefined;
};

WDZRNavigateur.prototype._nGetColonneSelonAlias = function _nGetColonneSelonAlias(sAliasColonne)
{
	var tabColonnes = this.m_tabColonnes;
	var i;
	var nLimiteI = this._nGetNbColonnes();
	for (i = 0; i < nLimiteI; i++)
	{
		if (tabColonnes[i].m_sAlias == sAliasColonne)
		{
			return i;
		}
	}
	return undefined;
};

// Recalcul les ruptures pour une ligne
WDZRNavigateur.prototype.__RupturesEntreLignes = function __RupturesEntreLignes (oLigne1, oLigne2)
{
	var nRuptures;
	if (oLigne1 && oLigne2)
	{
		nRuptures = WDZRLigne.prototype.ms_nRien;
		var tabRuptures = this.m_tabRuptures;
		var tabValeurs1 = oLigne1.tabGetValeurs();
		var tabValeurs2 = oLigne2.tabGetValeurs();
		var i;
		var nLimiteI = this._nGetNbRuptures();
		for (i = 0; i < nLimiteI; i++)
		{
			var nColonne = tabRuptures[i].m_nColonne;
			if (tabValeurs1[nColonne] != tabValeurs2[nColonne])
			{
				nRuptures |= (1 << i);
			}
		}
	}
	else
	{
		// Premiere (oLigne2) ou derniere ligne (oLigne1)
		nRuptures = WDZRLigne.prototype.ms_nTous;
	}

	if (oLigne1)
	{
		oLigne1.SetRupturesBas(nRuptures);
	}
	if (oLigne2)
	{
		oLigne2.SetRupturesHaut(nRuptures);
	}
};

// Notifie de la modication des lignes (recalcul les ruptures)
WDZRNavigateur.prototype.__OnLigneModification = function __OnLigneModification (nLigne)
{
	// Trouve les lignes
	var tabLignes = this.m_tabLignes;
	var oLignePrecedente = (0 < nLigne) ? tabLignes[nLigne - 1] : undefined;
	var oLigne = tabLignes[nLigne];
	var oLigneSuivante = (nLigne < this._nGetNbLignes() - 1) ? tabLignes[nLigne + 1] : undefined;

	// Si ce n'est pas la premiere ligne reporte les ruptures sur la ligne precedente (pas besoin de refaire le calcul des ruptures)
	this.__RupturesEntreLignes(oLignePrecedente, oLigne);
	this.__RupturesEntreLignes(oLigne, oLigneSuivante);
};

// Modifie une ligne avec un tableau de valeurs
// Version interne avec les parametres validees
WDZRNavigateur.prototype.__LigneModifie = function __LigneModifie(tabValeurs, nLigne)
{
	// Formate le tableau selon les attributs/colonnes
	var tabLigneValeurs = this.m_tabLignes[nLigne].tabGetValeurs();
	var tabColonnes = this.m_tabColonnes;
	var i;
	var nLimiteI = tabColonnes.length;
	for (i = 0; i < nLimiteI; i++)
	{
		tabLigneValeurs[i] = tabColonnes[i].oGetValeurInterne(tabValeurs[i]);
	}

	// Notifie de la modication des lignes (recalcul les ruptures)
	this.__OnLigneModification(nLigne);
};

// Affiche la ZR depuis un point donne
WDZRNavigateur.prototype.__LigneAffiche = function __LigneAffiche(nLigne)
{
	// @@@ A optimiser : reaffiche tout

	// Vide le HTML
	SupprimeFils(this.m_oHote);

	var tabHTML = [];
	var tabLignes = this.m_tabLignes;
	var i;
	var nLimiteI = this._nGetNbLignes();
	for (var i = 0; i < nLimiteI; i++)
	{
		this.__HTMLGenere(i, tabLignes[i], this.m_tabElementsHTML, tabHTML);
	}
	// A factoriser avec WDTable::GenereLignesHTML 
	if (bIE && clWDUtil.bBaliseEstTag(this.m_oHote, "table"))
	{
		var tabHTMLHote = (this.m_oHote.outerHTML + "").split("><");
		this.m_oHote.outerHTML = tabHTMLHote[0] + ">" + tabHTML.join("") + "<" + tabHTMLHote[tabHTMLHote.length - 1];
	}
	else
	{
		this.m_oHote.innerHTML = tabHTML.join("");
	}

	// Trouve l'hote (potentiellement ecrase par le outerHTML)
	this._vLiaisonHTML();

	// Si le champ est superposable, IE ne le redessine pas bien
	if (bIEQuirks)
	{
		var oExterne = _JGE(this.m_sAliasChamp, document, true, false);
		if (oExterne && (_JGCS(oExterne).position == "absolute"))
		{
			oExterne.className = oExterne.className;
		}
	}
};

// Presente une ligne de la ZR
WDZRNavigateur.prototype.__Montre = function __Montre(nLigne)
{
	// @@@
};

// Marque une ligne comme supprimee (ne l'enleve pas du tableau pour optimiser dans __LigneSupprimeTout)
WDZRNavigateur.prototype.__OnLigneSupprime = function __OnLigneSupprime(nLigne)
{
	// Notifie la ligne
	this.m_tabLignes[nLigne].OnSupprime();
	this.m_tabLignes[nLigne] = null;
};

// Supprime une ligne
WDZRNavigateur.prototype.__LigneSupprime = function __LigneSupprime(nLigne)
{
	// Supprime la ligne
	this.__OnLigneSupprime(nLigne);
	this.m_tabLignes.splice(nLigne, 1);

	this.m_oChampOcc.value = this._nGetNbLignes();

	// Notifie de la modication des lignes (recalcul les ruptures)
	this.__OnLigneModification(nLigne);
};

// Supprime toutes les lignes
WDZRNavigateur.prototype.__LigneSupprimeTout = function __LigneSupprimeTout()
{
	// Supprime toutes les lignes
	var i;
	var nLimiteI = this._nGetNbLignes();
	for (i = 0; i < nLimiteI; i++)
	{
		this.__OnLigneSupprime(i);
	}
	// Et vide le tableau
	this.m_tabLignes.length = 0;
	this.m_oChampOcc.value = this._nGetNbLignes();
};

// Fonction de comparaison pour le tri
WDZRNavigateur.prototype.__nTriCompare = function __nTriCompare (oLigne1, oLigne2)
{
	// Compare selon les criteres de tri
	var tabTri = this.m_tabTri;
	var tabValeurs1 = oLigne1.tabGetValeurs();
	var tabValeurs2 = oLigne2.tabGetValeurs();
	var tabColonne = this.m_tabColonnes;
	var i;
	var nLimiteI = tabTri.length;
	for (i = 0; i < nLimiteI; i++)
	{
		var oTri = tabTri[i];
		var nRes = oTri.m_fCompare.apply(tabColonne[oTri.m_nColonne], [tabValeurs1[oTri.m_nColonne], tabValeurs2[oTri.m_nColonne]]);
		// Si les valeurs ne sont pas egales
		if (0 != nRes)
		{
			// Si on inverse
			return oTri.m_bCroissant ? nRes : -nRes;
		}
	}
	// Egaux
	return 0;
};

// Recherche une ligne
WDZRNavigateur.prototype.__nLigneCherche = function __nLigneCherche (nColonne, sRecherche, bCommencePar, nLigneDebut)
{
	// Trouve la colonne et normalise la valeur recherchee
	var oColonne = this.m_tabColonnes[nColonne];
	var oRecherche = oColonne.oGetValeurInterne(sRecherche);

	// Trouve la fonction de comparaison
	var fCompare = oColonne.fGetCompare(bCommencePar);

	// Optimisation possible : en cas de table triee faire une recherche dichotomique

	// Recherche dans les lignes
	var tabLignes = this.m_tabLignes;
	var i;
	var nLimiteI = this._nGetNbLignes();
	for (i = nLigneDebut; i < nLimiteI; i++)
	{
		if (0 == fCompare.apply(oColonne, [oRecherche, this.__oGetValeurColonne(nColonne, tabLignes[i])]))
		{
			return i;
		}
	}

	return this.ms_nLigneInvalide;
};

WDZRNavigateur.prototype.__sLitPropriete = function __sLitPropriete(nLigne, oLigne, ePropriete, bPourCondition)
{
	switch (ePropriete)
	{
	case this.XML_CHAMP_PROP_NUM_VALEUR:
		// Donne la ligne en indice WL
		return this._nLigneLigneWL(nLigne);
	case this.XML_CHAMP_PROP_NUM_COULEURFOND:
		// Si la ligne a une couleur de fond (non disponible en WL navigateur actuellement)
		if (oLigne.m_sCouleurFond !== undefined)
		{
			return oLigne.m_sCouleurFond;
		}
		var sCouleur = -1;
		if (this.m_tabCouleurFond && this.m_tabCouleurFond.length)
		{
			// Notre premier indice est zero, mais c'est la premiere ligne qui ets impaire et le tableau est [impair, pair]
			// Donc +1 -1 => 0
			sCouleur = this.m_tabCouleurFond[nLigne % this.m_tabCouleurFond.length];
		}
		if ((sCouleur == -1) && !bPourCondition)
		{
			sCouleur = "transparent";
		}
		return sCouleur;

	case this.ms_nAttributRuptureLigneDebut:
		// Il n'y a pas encore de lignes invisibles
		// Donc c'est une simple division
		return (nLigne % this.m_nNbLignesLogiquesParLignePhysique) == 0;
	case this.ms_nAttributRuptureLigneFin:
		// Il n'y a pas encore de lignes invisibles
		// Donc c'est une simple division
		return (nLigne % this.m_nNbLignesLogiquesParLignePhysique) == (this.m_nNbLignesLogiquesParLignePhysique - 1);
	default:
		// @@@
//		alert(ePropriete);
		return "";
	}
};

// Trouve la valeur d'une colonne/ligne
WDZRNavigateur.prototype._oGetValeurColonne = function _oGetValeurColonne(nColonne, nLigne)
{
	return this.__oGetValeurColonne(nColonne, this.m_tabLignes[nLigne]);
};
// Trouve la valeur d'une colonne/ligne
WDZRNavigateur.prototype.__oGetValeurColonne = function __oGetValeurColonne(nColonne, oLigne)
{
	return oLigne.tabGetValeurs()[nColonne];
};


//////////////////////////////////////////////////////////////////////////
// Interface interne pour le WL

// Modifie une ligne avec un tableau de valeurs
WDZRNavigateur.prototype._LigneModifie = function _LigneModifie(tabValeurs, nLigneWL)
{
	var nLigne = this._nLigneWLLigne(nLigneWL, this._nGetSelection());
	if (nLigne !== undefined)
	{
		this.__LigneModifie(tabValeurs, nLigne);

		// Reaffiche la table
		this._LigneAffiche(nLigne);
	}
};

// Insere une ligne avec un tableau de valeurs
// Sans indice, insere a la fin (= ajout)
WDZRNavigateur.prototype._nLigneInsere = function _nLigneInsere(tabValeurs, nLigneWL)
{
	var nLigne = this._nLigneWLLigne(nLigneWL);
	// Ajoute une ligne vide
	var oLigne = new WDZRLigne(this._nGetNbColonnes());
	if (nLigne !== undefined)
	{
		// Ajoute au milieu
		this.m_tabLignes.splice(nLigne, 0, oLigne);
	}
	else
	{
		// Ajoute a la fin
		this.m_tabLignes.push(oLigne);
		nLigne = this._nGetNbLignes() - 1;
	}
	this.m_oChampOcc.value = this._nGetNbLignes();

	// Et modifie cette ligne
	this.__LigneModifie(tabValeurs, nLigne);

	// Reaffiche la table
	this._LigneAffiche(nLigne);

	// Conversion en numero de ligne WL
	return this._nLigneLigneWL(nLigne);
};

// Affiche la ZR depuis un point donne
WDZRNavigateur.prototype._LigneAffiche = function _LigneAffiche(nLigne, bMontre)
{
	// En fait on affiche depuis une ligne avant (la rupture a peut-etre ete modifiee)
	var nLigneAffiche = nLigne + ((0 < nLigne) ? -1 : 0);
	// Note que l'on devra afficher la ligne
	if (this.m_nLigneAfficheSuivante === undefined)
	{
		this.m_nLigneAfficheSuivante = nLigneAffiche;
	}
	else
	{
		this.m_nLigneAfficheSuivante = Math.min(nLigneAffiche, this.m_nLigneAfficheSuivante);
	}
	if (bMontre)
	{
		// Montre toujours la derniere ligne demandee
		this.m_bLigneMontreSuivante = bMontre;
		this.m_nLigneMontreSuivante = nLigne;
	}
	// Lance le setTimeout (dans le cas ou le WL ne valide pas explicitement la MAJ)
	this.nSetTimeoutUnique("_Affiche", 1);
};

WDZRNavigateur.prototype._Affiche = function _Affiche()
{
	// Supprime le Timeout de meme nom s'il existe
	this.AnnuleTimeXXX("_Affiche", false);
	// En fait on affiche depuis une ligne avant (la rupture a peut-etre ete modifiee)
	this.__LigneAffiche(this.m_nLigneAfficheSuivante);
	if (this.m_bLigneMontreSuivante)
	{
		this.__Montre(this.m_nLigneMontreSuivante);
	}
};

// Affiche la ZR depuis un point donne
WDZRNavigateur.prototype._nLigneDeplace = function _nLigneDeplace(nLigneSource, nLigneDestination, bEchange, bMontre)
{
	var tabLignes = this.m_tabLignes;
	var tabLigne = tabLignes[nLigneSource];
	if (bEchange)
	{
		tabLignes[nLigneSource] = tabLignes[nLigneDestination];
		tabLignes[nLigneDestination] = tabLigne;
		// Notifie de la modication des lignes (recalcul les ruptures)
		this.__OnLigneModification(nLigneSource);
		this.__OnLigneModification(nLigneDestination);
	}
	else
	{
		tabLignes.splice(nLigneSource, 1);
		// Decale la destination si besoin
		if (nLigneSource < nLigneDestination)
		{
			nLigneDestination--;
		}
		tabLignes.splice(nLigneDestination, 0, tabLigne);
		// Notifie de la modication des lignes (recalcul les ruptures)
		this.__OnLigneModification(nLigneDestination);
		this.__OnLigneModification(Math.max(0, nLigneSource - 1));
	}

	// Reaffiche la table depuis la position precedente
	this._LigneAffiche(Math.min(nLigneSource, nLigneDestination), bMontre);

	// Conversion en numero de ligne WL
	return this._nLigneLigneWL(nLigneDestination);
};

// Supprime une ligne
WDZRNavigateur.prototype._LigneSupprime = function _LigneSupprime(nLigne)
{
	// Supprime la ligne
	this.__LigneSupprime(nLigne);

	// Reaffiche la table depuis la position
	this._LigneAffiche(nLigne);
};

// Supprime toutes les lignes
WDZRNavigateur.prototype._LigneSupprimeTout = function _LigneSupprimeTout()
{
	// Supprime toutes les lignes
	this.__LigneSupprimeTout();

	// Reaffiche la table depuis le debut
	this._LigneAffiche(0);
};

// Retourne la ligne selectionnee
WDZRNavigateur.prototype._nGetSelection = function _nGetSelection(nLigneSiUndefined)
{
	// L'indice est en WL
	return this._nLigneWLLigne(this.m_oChampFormulaire.value);
};

// Informations sur les ruptures
WDZRNavigateur.prototype._nIndiceRupture = function _nIndiceRupture (sAliasRupture, nLigne)
{
	// Trouve l'indice de la rupture
	var nRupture = this._nGetRuptureSelonAlias(sAliasRupture);
	if (nRupture !== undefined)
	{
		// Remonte les lignes
		var tabLignes = this.m_tabLignes;
		var i;
		for (i = nLigne; 0 <= i; i--)
		{
			if (tabLignes[i].bGetRupture(nRupture))
			{
				// Trouve
				return this._nLigneLigneWL(i);
			}
		}
		// Normalement n'arrive pas (sauve si on n'a pas de lignes ou pas de selection)
	}
	return this.ms_nLigneInvalide;
};

// Tri
WDZRNavigateur.prototype._Tri = function _Tri (sSensColonnes)
{
	// Annule le precedent tri
	this._TriAnnule();

	// Memorise le tri
	var tabColonnes = this.m_tabColonnes;
	var bCroissant = true;
	var i;
	var nLimiteI;
	switch (sSensColonnes)
	{
	case "-":
		bCroissant = false;
		// Pas de break
	case "+":
		// Tri sur tous les attributs
		nLimiteI = this._nGetNbColonnes();
		for (i = 0; i < nLimiteI; i++)
		{
			this.m_tabTri.push({ m_fCompare : tabColonnes[i].fGetCompare(true), m_nColonne: i, m_bCroissant : bCroissant });
		}
		break;
	default:
		var tabColonnes = sSensColonnes.split("\t");
		nLimiteI = tabColonnes.length;
		for (i = 0; i < nLimiteI; i++)
		{
			var sAliasColonne = tabColonnes[i];
			bCroissant = true;
			switch(sAliasColonne.substring(0, 1))
			{
			case "-":
				bCroissant = false;
				// Pas de break
			case "+":
				sAliasColonne = sAliasColonne.substring(1);
				break;
			default:
				break;
			}
			var nColonne = this._nGetColonneSelonAlias(sAliasColonne);
			if (nColonne !== undefined)
			{
				this.m_tabTri.push({ m_fCompare : this.m_tabColonnes[nColonne].fGetCompare(true), m_nColonne: nColonne, m_bCroissant : bCroissant });
			}
		}
		break;
	}

	// Retri
	this._TriEncore();
};

// Retri
WDZRNavigateur.prototype._TriEncore = function _TriEncore ()
{
	// Uniquement si on a un tri
	if (0 < this.m_tabTri.length)
	{
		var oThis = this;
		this.m_tabLignes.sort(function() { return oThis.__nTriCompare(arguments[0], arguments[1]); });
	}
};

// Annule le tri
WDZRNavigateur.prototype._TriAnnule = function _TriAnnule (sSensColonnes)
{
	this.m_tabTri = [];
};

// Recherche une ligne
WDZRNavigateur.prototype._nLigneCherche = function _nLigneCherche (sAliasColonne, sRecherche, bCommencePar, nLigneDebut)
{
	// Trouve l'indice de la rupture
	var nColonne = this._nGetColonneSelonAlias(sAliasColonne);
	var nLigneResultat = this.ms_nLigneInvalide;
	if (nColonne !== undefined)
	{
		// Effectue la recherche
		nLigneResultat = this.__nLigneCherche(nColonne, sRecherche, bCommencePar, nLigneDebut);
	}

	// Conversion en numero de ligne WL
	return this._nLigneLigneWL(nLigneResultat);
};

// Enroule/deroule une ligne
// inverse si bDeroule n'est pas defini
WDZRNavigateur.prototype._EnrouleDeroule = function _EnrouleDeroule(nLigneWL, sAliasRupture, bDeroule)
{
	var nLigne = this._nLigneWLLigne(nLigneWL, this._nGetSelection());
	if (nLigne !== undefined)
	{
		// Trouve l'indice de la rupture
		var nRupture;
		var bRecursif;
		if (sAliasRupture === undefined)
		{
			nRupture = this._nGetNbRuptures() - 1;
			bRecursif = true;
		}
		else
		{
			nRupture = this._nGetRuptureSelonAlias(sAliasRupture);
			bRecursif = false;
		}
		if ((nRupture !== undefined) && (0 <= nRupture))
		{
			// Enroule deroule la rupture sur la ligne (si la rupture declenche a la ligne)
			this.m_tabLignes[nLigne].EnrouleDeroule(nRupture, bDeroule, bRecursif);

			// Reaffiche la table
			this._LigneAffiche(nLigne);
		}
	}
};

// Enroule/deroule toutes les lignes
WDZRNavigateur.prototype._EnrouleDerouleTout = function _EnrouleDerouleTout(bDeroule)
{
	var tabLignes = this.m_tabLignes;
	var i;
	var nLimiteI = this._nGetNbLignes();
	for (i = 0; i < nLimiteI; i++)
	{
		tabLignes[i].EnrouleDerouleTout(bDeroule);
	}

	// Reaffiche la table
	this._LigneAffiche(0);
};

// Conversion d'un numero de ligne WL en numero de ligne interne
WDZRNavigateur.prototype._nLigneWLLigne = function _nLigneWLLigne(nLigneWL, nLigneSiUndefined, nLigneSiInvalide, bAccepteLigneSelectionnee)
{
	if (bAccepteLigneSelectionnee && (nLigneWL === -1))
	{
		// Retourne l'indice interne
		nLigneWL = this._nGetSelection();
	}
	else if (nLigneWL === undefined)
	{
		// Si l'indice indefini
		nLigneWL = nLigneSiUndefined;
	}
	else
	{
		// Force la conversion en entier
		nLigneWL = parseInt(nLigneWL, 10);
		if (!isNaN(nLigneWL))
		{
			nLigneWL--;
		}
	}

	// Si la valeur est definie (ou transformee en definie depuis indefinie)
	if (nLigneWL !== undefined)
	{
		// Si la valeur est valide et dans les bornes
		if (!isNaN(nLigneWL) && (this._nGetNbLignes() > nLigneWL) && (0 <= nLigneWL))
		{
			return nLigneWL;
		}
		return nLigneSiInvalide;
	}
	else
	{
		return nLigneWL;
	}
};

// Conversion d'un numero de ligne interne en numero de ligne WL
WDZRNavigateur.prototype._nLigneLigneWL = function _nLigneLigneWL(nLigne)
{
	return (this.ms_nLigneInvalide != nLigne) ? (nLigne + 1) : this.ms_nLigneInvalide;
};

//////////////////////////////////////////////////////////////////////////
// Interface pour le WL

// Ajoute une ligne avec une chaine de valeurs
WDZRNavigateur.prototype.Ajoute = function Ajoute (sValeur)
{
	var bRes = (this.ms_nLigneInvalide != this._nLigneInsere(("" + sValeur).split("\t")));
	if (bRes)
	{
		// Lent mais juste : retrie la table si besoin
		this._TriEncore();
	}
	return bRes;
};

// Ajoute une ligne avec une serie de valeurs
WDZRNavigateur.prototype.AjouteLigne = function AjouteLigne ()
{
	var nRes = this._nLigneInsere(this.__tabArgumentsVersTableau(arguments, 0));
	if (this.ms_nLigneInvalide != nRes)
	{
		// Lent mais juste : retrie la table si besoin
		this._TriEncore();
	}
	return nRes;
};

// Modifie une ligne avec une chaine de valeurs
WDZRNavigateur.prototype.Modifie = function Modifie (sValeur, nLigneWL)
{
	this._LigneModifie(("" + sValeur).split("\t"), nLigneWL);
};

// Modifie une ligne avec une serie de valeurs
WDZRNavigateur.prototype.ModifieLigne = function ModifieLigne (nLigneWL)
{
	this._LigneModifie(this.__tabArgumentsVersTableau(arguments, 1), nLigneWL);
};

// Insere une ligne avec une chaine de valeurs
WDZRNavigateur.prototype.Insere = function Insere (sValeur, nLigneWL)
{
	// Pas de valeur de retour
	return (this.ms_nLigneInvalide != this._nLigneInsere(("" + sValeur).split("\t"), nLigneWL));
};

// Insere une ligne avec une serie de valeurs
WDZRNavigateur.prototype.InsereLigne = function InsereLigne (nLigneWL)
{
	this._nLigneInsere(this.__tabArgumentsVersTableau(arguments, 1), nLigneWL);
};

// Deplace une ligne
WDZRNavigateur.prototype.DeplaceLigne = function DeplaceLigne(nSourceWL, nDestinationWL, nOperation)
{
	var nLigneSource = this._nLigneWLLigne(nSourceWL, undefined, undefined, true);
	var nLigneDestination = this._nLigneWLLigne(nDestinationWL, undefined, undefined, true);
	if ((nLigneSource !== undefined) && (nLigneDestination !== undefined) && (nLigneSource != nLigneDestination))
	{
		return this._nLigneDeplace(nLigneSource, nLigneDestination, 0 != (nOperation & 0x80000000), 0 != (nOperation & 65536));
	}
	else
	{
		// Erreur (pas this.ms_nLigneInvalide mais 0 pour cette fonction)
		return 0;
	}
};

// Supprime une ligne
WDZRNavigateur.prototype.Supprime = function Supprime(nLigneWL)
{
	var nLigne = this._nLigneWLLigne(nLigneWL, this._nGetSelection());
	if (nLigne !== undefined)
	{
		this._LigneSupprime(nLigne);
	}
};

// Supprime toutes les lignes
WDZRNavigateur.prototype.SupprimeTout = function SupprimeTout()
{
	this._LigneSupprimeTout();
};

// Nombre d'occurrence de la zone repetee
WDZRNavigateur.prototype.Occurrence = function Occurrence(nIndicateur)
{
	// Valeur par defaut = Nb colonnes
	if (nIndicateur === undefined)
	{
		nIndicateur = 1
	}
	switch (nIndicateur)
	{
	case 1:
		// toTotal
		return this._nGetNbLignes();
	case 2:
		// toColonne
		return this._nGetNbColonnes();
	default:
		return this.ms_nLigneInvalide;
	}
};

// Informations sur les ruptures
WDZRNavigateur.prototype.IndiceRupture = function IndiceRupture(sAliasRupture, nLigneWL)
{
	var nLigne = this._nLigneWLLigne(nLigneWL, this._nGetSelection());
	if (nLigne !== undefined)
	{
		return this._nIndiceRupture(sAliasRupture, nLigne);
	}
	else
	{
		return this.ms_nLigneInvalide
	}
};

// Tri
WDZRNavigateur.prototype.Trie = function Trie(sSensColonnes, bTrie)
{
	if (bTrie)
	{
		this._Tri(sSensColonnes);
	}
	else
	{
		this._TriAnnule(sSensColonnes);
	}
};

// Recherche
WDZRNavigateur.prototype.Cherche = function Cherche(sAliasColonne, sRecherche, nTypeRecherche, nLigneDebutWL)
{
	var nLigneDebut = this._nLigneWLLigne(nLigneDebutWL, 0, 0);
	return this._nLigneCherche(sAliasColonne, sRecherche, (0 == nTypeRecherche), nLigneDebut);
};

// Enroule une rupture
WDZRNavigateur.prototype.Enroule = function Enroule(nLigneWL, sAliasRupture)
{
	this._EnrouleDeroule(nLigneWL, sAliasRupture, false);
};

// Enroule tout
WDZRNavigateur.prototype.EnrouleTout = function EnrouleTout()
{
	this._EnrouleDerouleTout(false);
};

// Deroule une rupture
WDZRNavigateur.prototype.Deroule = function Deroule(nLigneWL, sAliasRupture)
{
	this._EnrouleDeroule(nLigneWL, sAliasRupture, true);
};

// Deroule tout
WDZRNavigateur.prototype.DerouleTout = function DerouleTout()
{
	this._EnrouleDerouleTout(true);
};

// Inverse l'enroulement
WDZRNavigateur.prototype.EnrouleDeroule = function EnrouleDeroule(nLigneWL, sAliasRupture)
{
	this._EnrouleDeroule(nLigneWL, sAliasRupture);
};

// Acces WL au valeur des colonnes (lecture)
WDZRNavigateur.prototype.oGetValeurColonne = function oGetValeurColonne(sAliasColonne, nLigneWL)
{
	var nLigne = this._nLigneWLLigne(nLigneWL, this._nGetSelection());
	var nColonne = this._nGetColonneSelonAlias(sAliasColonne);
	// Si la ligne et la colonne sont valides
	if ((nColonne !== undefined) && (nLigne !== undefined))
	{
		return this._oGetValeurColonne(nColonne, nLigne);
	}
	else
	{
		return "";
	}
};
// Acces WL au lignes (ecriture)
WDZRNavigateur.prototype.tabGetLigneSet = function tabGetLigneSet(nLigneWL)
{
	var nLigne = this._nLigneWLLigne(nLigneWL, this._nGetSelection());
	// Si la ligne et la colonne sont valides
	if (nLigne !== undefined)
	{
		// Note la MAJ de la ligne
		this._LigneAffiche(nLigne);

		// Note la ligne pour le rafraichissement en fin de PCode
		return this.m_tabLignes[nLigne].tabGetValeurs();
	}
	else
	{
		return [];
	}
};

// Demande l'affichage immediat de la table
WDZRNavigateur.prototype.OnChange = function OnChange()
{
	this._Affiche();
};

//////////////////////////////////////////////////////////////////////////
// Generateur HTML

// Parse le HTML
WDZRNavigateur.prototype.__HTMLParse = function __HTMLParse()
{
	// m_tabElementsHTML est un tableau d'objets :
	// - Balise fixe :			{ vVersHTML : this.VersHTML_Fixe, m_sValeur : (Valeur chaine) }
	// - Balise dynamique		{ vVersHTML : this.VersHTML_Propriete, m_oPropriete : { <m_nColonne> <, m_ePropriete> <, m_eConversion> }
	//																					^				^				^
	//																			Si sur attribut			^			Si conversion
	//																						Si propriete (sur ZR)
	// - Balise condition		{ vVersHTML : this.VersHTML_Condition, m_sValeur : (Valeur chaine a tester), m_bDifferent : <!= au lieu de ==>, m_tabElementsHTML: <Tableau interne>, m_oPropriete : <Idem balise dynamique> }
	this.m_tabElementsHTML = [];
	var sHTML = clWDUtil.sGetHTMLDansCommentaire(this.m_oHote);

	// Parse le HTML avec le version interne (factorisation avec le code des [%SI%])
	this.__nHTMLParseInterne(sHTML, 0, this.m_tabElementsHTML);
};

// Parse le HTML (version interne :factorisation avec le code des [%SI%])
WDZRNavigateur.prototype.__nHTMLParseInterne = function __nHTMLParseInterne(sHTML, nDebut, tabElementsHTML)
{
	while (1)
	{
		// Trouve le prochain [%
		var nPosition = sHTML.indexOf(this.ms_sDynO, nDebut);
		// Ajoute un bloc fixe si besoin
		nDebut = this.__nHTMLParseFixe(sHTML, nDebut, nPosition, tabElementsHTML)
		// Si on n'a plus de bloc : fini
		if (-1 == nPosition)
		{
			// Ici normalement nDebut == sHTML.length
			return nDebut;
		}
		// Ici normalement nDebut == nPosition
		// Si on a un [%FIN%] => fin du parsing de la condition
		if (sHTML.substr(nPosition, this.ms_sDynFin.length) == this.ms_sDynFin)
		{
			return nPosition + this.ms_sDynFin.length;
		}
		// Si on est sur un [%SI%]
		else if (sHTML.substr(nPosition, this.ms_sDynSi.length) == this.ms_sDynSi)
		{
			// Et parse la condition
			nDebut = this.__nHTMLParseSi(sHTML, nPosition, tabElementsHTML)
		}
		// Parse la valeur
		else
		{
			nDebut = this.__nHTMLParsePropriete(sHTML, nPosition, tabElementsHTML)
		}
	}
};

// - Balise fixe :			{ vVersHTML : this.VersHTML_Fixe, m_sValeur : (Valeur chaine) }
WDZRNavigateur.prototype.__nHTMLParseFixe = function __nHTMLParseFixe(sHTML, nDebut, nPosition, tabElementsHTML)
{
	var sValeur;
	if (-1 != nPosition)
	{
		sValeur = sHTML.substring(nDebut, nPosition);
	}
	else
	{
		sValeur = sHTML.substring(nDebut);
	}
	// Uniquement si on a une valeur
	if (sValeur.length > 0)
	{
		tabElementsHTML.push({ vVersHTML : this.VersHTML_Fixe, m_sValeur : sValeur });
	}
	return nDebut + sValeur.length;
};

// - Balise condition		{ vVersHTML : this.VersHTML_Condition, m_sValeur : (Valeur chaine a tester), m_bDifferent : <!= au lieu de ==>, m_tabElementsHTML: <Tableau interne>, m_oPropriete : <Idem balise dynamique> }
WDZRNavigateur.prototype.__nHTMLParseSi = function __nHTMLParseFixe(sHTML, nDebut, tabElementsHTML)
{
	var oElement = { vVersHTML: this.VersHTML_Condition, m_sValeur: "", m_bDifferent: false, m_tabElementsHTML: [], m_oPropriete: null };

	// Ignore le [%SI%]
	nDebut += this.ms_sDynSi.length;
	// Trouve le [%ALORS%]
	var nPositionAlors = sHTML.indexOf(this.ms_sDynAlors, nDebut);
	// Parse la condition
	var sCondition = sHTML.substring(nDebut, nPositionAlors);
	var nPositionCondition = sCondition.indexOf(this.ms_sConditionDifferent);
	var nPositionConditionFin;
	if (-1 == nPositionCondition)
	{
		nPositionCondition = sCondition.indexOf(this.ms_sConditionEgal);
		// Ne sera pas utilise si nPosition est invalide
		nPositionConditionFin = nPositionCondition + this.ms_sConditionEgal.length;
		oElement.m_bDifferent = false;
	}
	else
	{
		nPositionConditionFin = nPositionCondition + this.ms_sConditionDifferent.length;
		oElement.m_bDifferent = true;
	}
	if (-1 != nPositionConditionFin)
	{
		oElement.m_oPropriete = this.__oParsePropriete(sCondition.substring(0, nPositionCondition));
		oElement.m_sValeur = sCondition.substring(nPositionConditionFin, nPositionAlors);

		tabElementsHTML.push(oElement);
	}
	// Et analyse le contenu
	return this.__nHTMLParseInterne(sHTML, nPositionAlors + this.ms_sDynAlors.length, oElement.m_tabElementsHTML);
};

// Parse une propriete [%ALIAS_ZR<;format>%], [%ALIAS_ZR..PROP<;format>%], [%ALIAS_ATTRIBUT<;format>%]
// - Balise dynamique		{ vVersHTML : this.VersHTML_Propriete, m_oPropriete : { <m_nColonne> <, m_ePropriete> <, m_eConversion> }
//																					^				^				^
//																			Si sur attribut			^			Si conversion
//																					Si propriete (sur ZR)
WDZRNavigateur.prototype.__nHTMLParsePropriete = function __nHTMLParsePropriete(sHTML, nDebut, tabElementsHTML)
{
	// Ignore le [%
	nDebut += this.ms_sDynO.length;
	// Trouve le %]
	var nPosition = sHTML.indexOf(this.ms_sDynF, nDebut);
	// Parse la propriete
	tabElementsHTML.push({ vVersHTML : this.VersHTML_Propriete, m_oPropriete : this.__oParsePropriete(sHTML.substring(nDebut, nPosition)) });
	return nPosition + this.ms_sDynF.length;
};

// { <m_nColonne> <, m_ePropriete> <, m_eConversion> }
WDZRNavigateur.prototype.__oParsePropriete = function __oParsePropriete(sPropriete)
{
	var oPropriete = { m_ePropriete : this.XML_CHAMP_PROP_NUM_VALEUR };
	// Extrait la conversion
	// sPropriete est de la forme : ALIAS, ALIAS..PROP, ALIAS..PROP;CONV
	var nPositionConversion	= sPropriete.indexOf(this.ms_sConversion);
	if (-1 != nPositionConversion)
	{
		oPropriete.m_eConversion = parseInt(sPropriete.substring(nPositionConversion + this.ms_sConversion.length), 10);
		// Extrait la conversion : pour n'avoir que deux formes : ALIAS, ALIAS..PROP
		sPropriete = sPropriete.substring(0, nPositionConversion);
	}
	// Extrait la propriete
	// sPropriete est de la forme : ALIAS, ALIAS..PROP
	var nPositionPropriete = sPropriete.indexOf(this.ms_sPropriete);
	if (-1 != nPositionPropriete)
	{
		oPropriete.m_ePropriete = this.__eParsePPPropriete(sPropriete.substring(nPositionPropriete + this.ms_sPropriete.length));
		// Extrait la propriete : pour n'avoir que une formes : ALIAS
		sPropriete = sPropriete.substring(0, nPositionPropriete);
	}
	// Alias
	// sPropriete est de la forme : ALIAS
	oPropriete.m_nColonne = this._nGetColonneSelonAlias(sPropriete);
	return oPropriete;
};
WDZRNavigateur.prototype.__eParsePPPropriete = function __eParsePPPropriete(sPropriete)
{
	switch (sPropriete)
	{
	case "COULEURFOND":
		return this.XML_CHAMP_PROP_NUM_COULEURFOND;
	case "RUPTURELIGNE_DEBUT":
		return this.ms_nAttributRuptureLigneDebut;
	case "RUPTURELIGNE_FIN":
		return this.ms_nAttributRuptureLigneFin;
	default:
		// @@@
//		alert(sPropriete);
		return this.XML_CHAMP_PROP_NUM_VALEUR;
	}
};

// Genere le HTML
WDZRNavigateur.prototype.__HTMLGenere = function __HTMLGenere(nLigne, oLigne, tabElementsHTML, tabHTML)
{
	var i;
	var nLimiteI = tabElementsHTML.length;
	for (i = 0; i < nLimiteI; i++)
	{
		tabElementsHTML[i].vVersHTML.apply(this, [nLigne, oLigne, tabElementsHTML[i], tabHTML]);
	}
};

// Fonctions specialises pour les sous objets
WDZRNavigateur.prototype.VersHTML_Fixe = function VersHTML_Fixe(nLigne, oLigne, oElement, tabHTML)
{
	tabHTML.push(oElement.m_sValeur);
};
WDZRNavigateur.prototype.VersHTML_Propriete = function VersHTML_Propriete (nLigne, oLigne, oElement, tabHTML)
{
	// Trouve la valeur pour la ligne courante
	tabHTML.push(this.__sGetPropriete(nLigne, oLigne, oElement.m_oPropriete, false));
};
WDZRNavigateur.prototype.VersHTML_Condition = function VersHTML_Condition(nLigne, oLigne, oElement, tabHTML)
{
	var bRes = (oElement.m_sValeur == this.__sGetPropriete(nLigne, oLigne, oElement.m_oPropriete, true));
	if (oElement.m_bDifferent ? !bRes : bRes)
	{
		this.__HTMLGenere(nLigne, oLigne, oElement.m_tabElementsHTML, tabHTML);
	}
};

// Trouve la valeur d'une propriete (factorisation entre VersHTML_Propriete et VersHTML_Condition)
WDZRNavigateur.prototype.__sGetPropriete = function __sGetPropriete(nLigne, oLigne, oPropriete, bPourCondition)
{
	// { <m_nColonne> <, m_ePropriete> <, m_eConversion> }
	var sValeur
	if (oPropriete.m_nColonne !== undefined)
	{
		sValeur = this.__oGetValeurColonne(oPropriete.m_nColonne, oLigne);
	}
	else
	{
		sValeur = this.__sLitPropriete(nLigne, oLigne, oPropriete.m_ePropriete, bPourCondition);
	}

	return this.__sConversion(sValeur, this.m_eConversion);
};

// Conversion en ecriture
WDZRNavigateur.prototype.__sConversion = function __sConversion(sValeur, eConversion)
{
	if (eConversion !== undefined)
	{
		switch (eConversion)
		{
		// @@@
		default:
		}
	}
	return sValeur;
};
